@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,8 +37,10 @@
 #ifndef LIBTORRENT_PEER_CONNECTION_LIST_H
 #define LIBTORRENT_PEER_CONNECTION_LIST_H
 
+#include <functional>
+#include <list>
 #include <vector>
-#include <sigc++/signal.h>
+
 #include <torrent/common.h>
 #include <torrent/hash_string.h>
 
@@ -65,7 +67,8 @@ public:
   typedef std::vector<Peer*>         base_type;
   typedef std::vector<HashString>    queue_type;
   typedef uint32_t                   size_type;
-  typedef sigc::signal1<void, Peer*> signal_peer_type;
+  typedef std::function<void (Peer*)> slot_peer_type;
+  typedef std::list<slot_peer_type>        signal_peer_type;
 
   typedef PeerConnectionBase* (*slot_new_conn_type)(bool encrypted);
 
@@ -128,7 +131,9 @@ protected:
   // Does not do the usual cleanup done by 'erase'.
   void                clear() LIBTORRENT_NO_EXPORT;
 
-  // Returns false if the connection was not added, the caller is then
+  bool                want_connection(PeerInfo* p, Bitfield* bitfield);
+
+  // Returns NULL if the connection was not added, the caller is then
   // responsible for cleaning up 'fd'.
   //
   // Clean this up, don't use this many arguments.
